@@ -1,4 +1,4 @@
-"""Context processors used by the CMS."""
+'''Context processors used by the CMS.'''
 
 from django.conf import settings as django_settings
 
@@ -6,9 +6,9 @@ from . import VERSION
 
 
 def settings(request):
-    """Gives the settings object to the template."""
+    '''Makes Django settings available in templates.'''
     context = {
-        "settings": django_settings,
+        'settings': django_settings,
         'cms_version': VERSION,
     }
     return context
